Package: GUniFrac
Type: Package
Title: Generalized UniFrac Distances, Distance-Based Multivariate
        Methods and Feature-Based Univariate Methods for Microbiome
        Data Analysis
Version: 1.9
Date: 2025-08-25
Authors@R: c(person(given = "Jun",
                        family = "Chen",
                        role = c("aut", "cre"),
                        email = "chen.jun2@mayo.edu"),
                 person(given = "Xianyang",
                        family = "Zhang",
                        role = "aut"),
                 person(given = "Lu",
                        family = "Yang",
                        role = "aut"),
                 person(given = "Lujun",
                        family = "Zhang",
                        role = "aut"))
Description: A suite of methods for powerful and robust microbiome data analysis including data normalization, data simulation, community-level association testing and differential abundance analysis. It implements generalized UniFrac distances,  Geometric Mean of Pairwise Ratios (GMPR) normalization, semiparametric data simulator, distance-based statistical methods, and feature-based statistical methods. The distance-based statistical methods include three extensions of PERMANOVA: (1) PERMANOVA using the Freedman-Lane permutation scheme, (2) PERMANOVA omnibus test using multiple matrices, and  (3) analytical approach to approximating PERMANOVA p-value. Feature-based statistical methods include linear model-based methods for differential abundance analysis of zero-inflated high-dimensional compositional data. 
Depends: R (>= 3.5.0)
Suggests: ade4, knitr, markdown, ggpubr
Imports: Rcpp (>= 0.12.13), vegan, ggplot2, matrixStats, Matrix, ape,
        parallel, stats, utils, statmod, rmutil, dirmult, MASS,
        ggrepel, foreach, modeest, inline, methods
LinkingTo: Rcpp
NeedsCompilation: yes
VignetteBuilder: knitr
License: GPL-3
Encoding: UTF-8
Packaged: 2025-08-25 19:13:10 UTC; chen.jun2
Author: Jun Chen [aut, cre],
  Xianyang Zhang [aut],
  Lu Yang [aut],
  Lujun Zhang [aut]
Maintainer: Jun Chen <chen.jun2@mayo.edu>
Repository: CRAN
Date/Publication: 2025-08-25 21:20:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-28 15:31:44 UTC; unix
Archs: GUniFrac.so.dSYM
