importFrom(vegan, adonis, vegdist)
importFrom(ape, is.rooted, drop.tip)
import(statmod)
import(matrixStats)
import(stats)
importFrom(inline, cxxfunction)
importFrom(methods, signature)
importFrom(Rcpp, evalCpp)
importFrom(rmutil, dbetabinom)
importFrom(Matrix, nearPD)
importFrom(MASS, rnegbin)
importFrom(parallel, mclapply, makeCluster, stopCluster, clusterEvalQ,
           parApply, parLapply, parSapply, parRapply, parCapply)
importFrom(utils, getFromNamespace)   
import(foreach)
import(ggplot2)
import(ggrepel)
importFrom(modeest, mlv)
importFrom("grDevices", "dev.off", "hcl", "pdf")

export(GUniFrac)
export(Rarefy)
export(PermanovaG)
export(PermanovaG2)
export(SimulateMSeq)
export(SimulateMSeqC)
export(dmanova)
export(adonis3)
export(ZicoSeq)
export(GMPR)
export(ZicoSeq.plot)
export(dICC)
export(dICC.SE.asympt)
export(dICC.SE.bt)

useDynLib(GUniFrac)

