# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

PairwiseD <- function(cum, b, a) {
    .Call('_GUniFrac_PairwiseD', PACKAGE = 'GUniFrac', cum, b, a)
}

gmpr <- function(x, min_ct, intersect_no) {
    .Call('_GUniFrac_gmpr', PACKAGE = 'GUniFrac', x, min_ct, intersect_no)
}

